@@ -213,7 +213,7 @@ def test_order_by():
 
 def test_order_by_desc():
     """Test ORDER BY with DESC"""
-    query = Users.select().order_by((Users.id, 'DESC'))
+    query = Users.select().order_by(Users.id.desc())
     sql, params = query.render()
 
     assert 'ORDER BY users.id DESC' in sql
@@ -221,7 +221,39 @@ def test_order_by_desc():
 
 def test_order_by_multiple():
     """Test ORDER BY with multiple columns"""
-    query = Users.select().order_by(Users.username, (Users.id, 'DESC'))
+    query = Users.select().order_by(Users.username, Users.id.desc())
+    sql, params = query.render()
+
+    assert 'ORDER BY users.username ASC, users.id DESC' in sql
+
+
+def test_order_by_asc_method():
+    """Test ORDER BY with .asc() method"""
+    query = Users.select().order_by(Users.username.asc())
+    sql, params = query.render()
+
+    assert 'ORDER BY users.username ASC' in sql
+
+
+def test_order_by_desc_method():
+    """Test ORDER BY with .desc() method"""
+    query = Users.select().order_by(Users.id.desc())
+    sql, params = query.render()
+
+    assert 'ORDER BY users.id DESC' in sql
+
+
+def test_order_by_mixed_methods():
+    """Test ORDER BY with mixed .asc() and .desc() methods"""
+    query = Users.select().order_by(Users.username.asc(), Users.id.desc())
+    sql, params = query.render()
+
+    assert 'ORDER BY users.username ASC, users.id DESC' in sql
+
+
+def test_order_by_mixed_syntax():
+    """Test ORDER BY with mixed method calls and bare columns"""
+    query = Users.select().order_by(Users.username, Users.id.desc())
     sql, params = query.render()
 
     assert 'ORDER BY users.username ASC, users.id DESC' in sql
@@ -242,7 +274,7 @@ def test_complex_query():
              .join(Users, Posts.user_id == Users.id)
              .where(Posts.id > 100)
              .where(Users.id >= 5)
-             .order_by((Posts.id, 'DESC'))
+             .order_by(Posts.id.desc())
              .limit(20))
     sql, params = query.render()
 
@@ -351,7 +383,7 @@ def test_schema_in_update():
         id: Column
         name: Column
 
-    query = Accounts.update({'name': 'Updated Account'}).where(Accounts.id == '1')
+    query = Accounts.update(name='Updated Account').where(Accounts.id == '1')
     sql, params = query.render()
 
     assert 'UPDATE other.accounts SET' in sql
@@ -480,7 +512,7 @@ def test_complex_aggregation_query():
              .where(Posts.id > 100)
              .group_by(Posts.user_id)
              .having(Posts.id > 5)
-             .order_by((Posts.user_id, 'DESC'))
+             .order_by(Posts.user_id.desc())
              .limit(10)
              .offset(5))
     sql, params = query.render()
@@ -601,7 +633,7 @@ def test_table_insert_chained_with_returning():
 
 def test_table_update_with_where():
     """Test table.update() with WHERE clause"""
-    builder = Users.update({'username': 'bob_updated'}).where(Users.id == 5)
+    builder = Users.update(username='bob_updated').where(Users.id == 5)
     assert isinstance(builder, UpdateBuilder)
 
     sql, params = builder.render()
@@ -615,7 +647,7 @@ def test_table_update_with_where():
 
 def test_table_update_multiple_conditions():
     """Test table.update() with multiple WHERE conditions"""
-    builder = (Users.update({'username': 'bob_updated', 'email': 'new@example.com'})
+    builder = (Users.update(username='bob_updated', email='new@example.com')
                .where(Users.id > 10)
                .where(Users.created_at == None))
 
@@ -630,7 +662,7 @@ def test_table_update_multiple_conditions():
 
 def test_table_update_with_returning():
     """Test table.update() with RETURNING"""
-    builder = Users.update({'username': 'bob_updated'}).where(Users.id == 5).returning()
+    builder = Users.update(username='bob_updated').where(Users.id == 5).returning()
     sql, params = builder.render()
 
     assert 'UPDATE users SET' in sql
@@ -681,7 +713,7 @@ def test_table_delete_with_returning():
 def test_update_with_t_string_where():
     """Test UpdateBuilder with raw t-string WHERE clause"""
     min_age = 18
-    builder = Users.update({'username': 'adult'}).where(t"age >= {min_age}")
+    builder = Users.update(username='adult').where(t"age >= {min_age}")
 
     sql, params = builder.render()
 
@@ -1062,7 +1094,7 @@ def test_update_with_onupdate_default():
         title = SAColumn(String)
         updated_at = SAColumn(String, onupdate=lambda: 'updated_timestamp')
 
-    query = Articles.update({'title': 'Updated Title'}).where(Articles.id == '123')
+    query = Articles.update(title='Updated Title').where(Articles.id == '123')
     sql, params = query.render()
 
     assert 'UPDATE articles SET' in sql
@@ -1082,7 +1114,7 @@ def test_update_overrides_onupdate():
         title = SAColumn(String)
         updated_at = SAColumn(String, onupdate=lambda: 'auto_timestamp')
 
-    query = Articles.update({'title': 'Updated', 'updated_at': 'manual_timestamp'}).where(Articles.id == '123')
+    query = Articles.update(title='Updated', updated_at='manual_timestamp').where(Articles.id == '123')
     sql, params = query.render()
 
     assert 'UPDATE articles SET' in sql
@@ -1140,14 +1172,14 @@ def test_returning_cols_validation_update():
     import pytest
 
     # Test with malicious returning column
-    query = Users.update({'username': 'hacked'})
+    query = Users.update(username='hacked').all_rows()
     builder = query.returning("id, (SELECT password FROM admin_users LIMIT 1) AS stolen")
 
     with pytest.raises(ValueError, match="Invalid RETURNING column name"):
         builder.render()
 
     # Test with valid returning columns (should work)
-    query2 = Users.update({'username': 'updated'})
+    query2 = Users.update(username='updated')
     builder2 = query2.where(Users.id == 5).returning("id", "username")
     sql, params = builder2.render()
 
@@ -1159,7 +1191,7 @@ def test_returning_cols_validation_delete():
     import pytest
 
     # Test with malicious returning column
-    query = Users.delete()
+    query = Users.delete().all_rows()
     builder = query.returning("* FROM users; DROP TABLE secrets; --")
 
     with pytest.raises(ValueError, match="Invalid RETURNING column name"):
@@ -1190,3 +1222,46 @@ def test_conflict_cols_list_validation():
     sql, params = builder2.render()
 
     assert 'ON CONFLICT (id, email)' in sql
+
+
+def test_update_without_where_raises_error():
+    """Test that UPDATE without WHERE clause raises UnsafeQueryError"""
+    import pytest
+    from tsql.query_builder import UnsafeQueryError
+
+    builder = Users.update(username='updated')
+
+    with pytest.raises(UnsafeQueryError, match="UPDATE without WHERE clause requires explicit .all_rows()"):
+        builder.render()
+
+
+def test_update_with_all_rows_works():
+    """Test that UPDATE with .all_rows() bypasses safety check"""
+    builder = Users.update(username='updated').all_rows()
+    sql, params = builder.render()
+
+    assert 'UPDATE users SET' in sql
+    assert 'username = ?' in sql
+    assert 'WHERE' not in sql
+    assert params == ['updated']
+
+
+def test_delete_without_where_raises_error():
+    """Test that DELETE without WHERE clause raises UnsafeQueryError"""
+    import pytest
+    from tsql.query_builder import UnsafeQueryError
+
+    builder = Users.delete()
+
+    with pytest.raises(UnsafeQueryError, match="DELETE without WHERE clause requires explicit .all_rows()"):
+        builder.render()
+
+
+def test_delete_with_all_rows_works():
+    """Test that DELETE with .all_rows() bypasses safety check"""
+    builder = Users.delete().all_rows()
+    sql, params = builder.render()
+
+    assert 'DELETE FROM users' in sql
+    assert 'WHERE' not in sql
+    assert params == []
