@@ -5,6 +5,14 @@ from abc import ABC, abstractmethod
 
 from tsql import TSQL, t_join
 
+
+class UnsafeQueryError(Exception):
+    """Raised when attempting to render an UPDATE or DELETE query without a WHERE clause.
+
+    To perform mass updates or deletes, explicitly call .all_rows() to confirm intent.
+    """
+    pass
+
 # Optional SQLAlchemy support
 try:
     from sqlalchemy import MetaData, Table as SATable, Column as SAColumn
@@ -16,6 +24,17 @@ except ImportError:
     SAColumnType = None
 
 
+class OrderByClause:
+    """Represents a column with an ORDER BY direction (ASC/DESC)"""
+
+    def __init__(self, column: 'Column', direction: str):
+        self.column = column
+        self.direction = direction.upper()
+
+    def __repr__(self) -> str:
+        return f"OrderByClause({self.column!r}, {self.direction!r})"
+
+
 class Column:
     """Represents a bound column (table + column name) for building queries"""
 
@@ -140,6 +159,28 @@ class Column:
         """Create an IS NOT NULL condition"""
         return Condition(self, 'IS NOT', None)
 
+    def asc(self) -> OrderByClause:
+        """Create an ascending ORDER BY clause
+
+        Returns:
+            OrderByClause for use in order_by()
+
+        Example:
+            Users.select().order_by(Users.username.asc())
+        """
+        return OrderByClause(self, 'ASC')
+
+    def desc(self) -> OrderByClause:
+        """Create a descending ORDER BY clause
+
+        Returns:
+            OrderByClause for use in order_by()
+
+        Example:
+            Users.select().order_by(Users.created_at.desc())
+        """
+        return OrderByClause(self, 'DESC')
+
 
 class Table:
     """Base class for all table definitions. Provides query builder methods.
@@ -298,14 +339,18 @@ class Table:
         return InsertBuilder(cls, values)
 
     @classmethod
-    def update(cls, values: dict[str, Any]) -> 'UpdateBuilder':
+    def update(cls, **values: Any) -> 'UpdateBuilder':
         """Start building an UPDATE query
 
         Args:
-            values: Dictionary of column names and values to update
+            **values: Column names and values to update as keyword arguments
 
         Returns:
             UpdateBuilder for adding WHERE conditions
+
+        Example:
+            Users.update(username='bob', email='bob@example.com')
+            Or with dict unpacking: Users.update(**my_dict)
         """
         return UpdateBuilder(cls, values)
 
@@ -650,10 +695,27 @@ class UpdateBuilder(QueryBuilder):
 
         self._conditions: List[Union[Condition, Template]] = []
         self._returning_cols: Optional[List[str]] = None
+        self._requires_where: bool = True
 
     def where(self, condition: Union[Condition, Template]) -> 'UpdateBuilder':
         """Add a WHERE condition (multiple calls are ANDed together)"""
         self._conditions.append(condition)
+        self._requires_where = False
+        return self
+
+    def all_rows(self) -> 'UpdateBuilder':
+        """Explicitly confirm intent to update all rows without a WHERE clause.
+
+        By default, UPDATE queries without WHERE clauses will raise UnsafeQueryError
+        at render time. Call this method to bypass that safety check.
+
+        Returns:
+            self for method chaining
+
+        Example:
+            Users.update(status='inactive').all_rows()
+        """
+        self._requires_where = False
         return self
 
     def returning(self, *columns: str) -> 'UpdateBuilder':
@@ -699,6 +761,11 @@ class UpdateBuilder(QueryBuilder):
 
     def render(self, style=None):
         """Convenience method to render the query directly"""
+        if self._requires_where:
+            raise UnsafeQueryError(
+                "UPDATE without WHERE clause requires explicit .all_rows() call to confirm intent. "
+                "This prevents accidentally updating all rows in the table."
+            )
         return self.to_tsql().render(style)
 
     def __repr__(self) -> str:
@@ -719,10 +786,27 @@ class DeleteBuilder(QueryBuilder):
         self.base_table = base_table
         self._conditions: List[Union[Condition, Template]] = []
         self._returning_cols: Optional[List[str]] = None
+        self._requires_where: bool = True
 
     def where(self, condition: Union[Condition, Template]) -> 'DeleteBuilder':
         """Add a WHERE condition (multiple calls are ANDed together)"""
         self._conditions.append(condition)
+        self._requires_where = False
+        return self
+
+    def all_rows(self) -> 'DeleteBuilder':
+        """Explicitly confirm intent to delete all rows without a WHERE clause.
+
+        By default, DELETE queries without WHERE clauses will raise UnsafeQueryError
+        at render time. Call this method to bypass that safety check.
+
+        Returns:
+            self for method chaining
+
+        Example:
+            Users.delete().all_rows()
+        """
+        self._requires_where = False
         return self
 
     def returning(self, *columns: str) -> 'DeleteBuilder':
@@ -767,6 +851,11 @@ class DeleteBuilder(QueryBuilder):
 
     def render(self, style=None):
         """Convenience method to render the query directly"""
+        if self._requires_where:
+            raise UnsafeQueryError(
+                "DELETE without WHERE clause requires explicit .all_rows() call to confirm intent. "
+                "This prevents accidentally deleting all rows in the table."
+            )
         return self.to_tsql().render(style)
 
     def __repr__(self) -> str:
@@ -834,11 +923,22 @@ class SelectQueryBuilder(QueryBuilder):
         """Add a RIGHT JOIN clause"""
         return self.join(table, on, 'RIGHT')
 
-    def order_by(self, *columns: Union[Column, tuple[Column, str]]) -> 'SelectQueryBuilder':
-        """Add ORDER BY clause. Pass (column, 'DESC') for descending"""
+    def order_by(self, *columns: Union[Column, OrderByClause]) -> 'SelectQueryBuilder':
+        """Add ORDER BY clause
+
+        Args:
+            columns: Column objects or OrderByClause objects (from .asc()/.desc())
+
+        Examples:
+            # Using .asc() and .desc() methods
+            Users.select().order_by(Users.username.asc(), Users.id.desc())
+
+            # Bare column defaults to ASC
+            Users.select().order_by(Users.username)
+        """
         for col in columns:
-            if isinstance(col, tuple):
-                self._order_by_columns.append(col)
+            if isinstance(col, OrderByClause):
+                self._order_by_columns.append((col.column, col.direction))
             else:
                 self._order_by_columns.append((col, 'ASC'))
         return self
